@@ -9,14 +9,16 @@ import publication
 import typing_extensions
 
 import aws_cdk.aws_budgets._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_sns._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@stefanfreitag/aws-budget-notifier",
-    "0.2.0",
+    "aws_budget_notifier",
+    "0.3.8",
     __name__[0:-6],
-    "aws-budget-notifier@0.2.0.jsii.tgz",
+    "aws_budget_notifier@0.3.8.jsii.tgz",
 )
 
 __all__ = [
